package com.ruoyi.system.service;

import java.util.List;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.system.domain.SettledMerchants;

/**
 * 入驻商家Service接口
 * 
 * @author boman
 * @date 2022-06-10
 */
public interface ISettledMerchantsService 
{
    /**
     * 查询入驻商家
     * 
     * @param businessId 入驻商家主键
     * @return 入驻商家
     */
    public SettledMerchants selectSettledMerchantsByBusinessId(Long businessId);

    /**
     * 根据政策类别获取入驻商家详细信息
     * @param menuId
     * @return
     */
    public List<SettledMerchants> selectSettledMerchantsByMenuId(Long menuId);

    /**
     * 查询入驻商家列表
     * 
     * @param settledMerchants 入驻商家
     * @return 入驻商家集合
     */
    public List<SettledMerchants> selectSettledMerchantsList(SettledMerchants settledMerchants);

    /**
     * 新增入驻商家
     * 
     * @param settledMerchants 入驻商家
     * @return 结果
     */
    public AjaxResult insertSettledMerchants(SettledMerchants settledMerchants);

    /**
     * 修改入驻商家
     * 
     * @param settledMerchants 入驻商家
     * @return 结果
     */
    public int updateSettledMerchants(SettledMerchants settledMerchants);

    /**
     * 批量删除入驻商家
     * 
     * @param businessIds 需要删除的入驻商家主键集合
     * @return 结果
     */
    public int deleteSettledMerchantsByBusinessIds(Long[] businessIds);

    /**
     * 删除入驻商家信息
     * 
     * @param businessId 入驻商家主键
     * @return 结果
     */
    public int deleteSettledMerchantsByBusinessId(Long businessId);

    public SettledMerchants selectByPhone(String businessPhone);
}
